@@ -1,11 +1,16 @@
+# -*- coding: utf-8 -*-
+
 from __future__ import print_function
-import msgpack
 import socket
 import threading
 import time
 
+import msgpack
+
+
 _global_sender = None
 
+
 def setup(tag, **kwargs):
     host = kwargs.get('host', 'localhost')
     port = kwargs.get('port', 24224)
@@ -13,15 +18,17 @@ def setup(tag, **kwargs):
     global _global_sender
     _global_sender = FluentSender(tag, host=host, port=port)
 
+
 def get_global_sender():
     return _global_sender
 
+
 class FluentSender(object):
     def __init__(self,
                  tag,
                  host='localhost',
                  port=24224,
-                 bufmax=1*1024*1024,
+                 bufmax=1 * 1024 * 1024,
                  timeout=3.0,
                  verbose=False):
 
@@ -36,10 +43,10 @@ class FluentSender(object):
         self.pendings = None
         self.packer = msgpack.Packer()
         self.lock = threading.Lock()
-        
+
         try:
             self._reconnect()
-        except:
+        except Exception:
             # will be retried in emit()
             self._close()
 
@@ -48,8 +55,8 @@ class FluentSender(object):
         self.emit_with_time(label, cur_time, data)
 
     def emit_with_time(self, label, timestamp, data):
-        bytes = self._make_packet(label, timestamp, data)
-        self._send(bytes)
+        bytes_ = self._make_packet(label, timestamp, data)
+        self._send(bytes_)
 
     def _make_packet(self, label, timestamp, data):
         if label:
@@ -61,25 +68,25 @@ class FluentSender(object):
             print(packet)
         return self.packer.pack(packet)
 
-    def _send(self, bytes):
+    def _send(self, bytes_):
         self.lock.acquire()
         try:
-            self._send_internal(bytes)
+            self._send_internal(bytes_)
         finally:
             self.lock.release()
 
-    def _send_internal(self, bytes):
+    def _send_internal(self, bytes_):
         # buffering
         if self.pendings:
-            self.pendings += bytes
-            bytes = self.pendings
+            self.pendings += bytes_
+            bytes_ = self.pendings
 
         try:
             # reconnect if possible
             self._reconnect()
 
             # send message
-            self.socket.sendall(bytes)
+            self.socket.sendall(bytes_)
 
             # send finished
             self.pendings = None
@@ -91,13 +98,18 @@ class FluentSender(object):
                 # TODO: add callback handler here
                 self.pendings = None
             else:
-                self.pendings = bytes
+                self.pendings = bytes_
 
     def _reconnect(self):
         if not self.socket:
-            sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
-            sock.settimeout(self.timeout)
-            sock.connect((self.host, self.port))
+            if self.host.startswith('unix://'):
+                sock = socket.socket(socket.AF_UNIX, socket.SOCK_STREAM)
+                sock.settimeout(self.timeout)
+                sock.connect(self.host[len('unix://'):])
+            else:
+                sock = socket.socket(socket.AF_INET, socket.SOCK_STREAM)
+                sock.settimeout(self.timeout)
+                sock.connect((self.host, self.port))
             self.socket = sock
 
     def _close(self):
